--------------------------------------------------------------------------------
-- sram_ethernet_0_wrapper.vhd
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;

-- synthesis translate_off
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;
-- synthesis translate_on

LIBRARY sram_ethernet_v1_00_a;
USE sram_ethernet_v1_00_a.ALL;

ENTITY sram_ethernet_0_wrapper IS
PORT (
	-- instance sram_ethernet_0
	ETH_CS : OUT STD_LOGIC;
	ETH_IOCS : IN STD_LOGIC;
	ETH_IREQ : IN STD_LOGIC;
	ETH_RDY_DTAK : IN STD_LOGIC;
	OPB_Clk : IN STD_LOGIC;
	PB_A : OUT STD_LOGIC_VECTOR(0 TO 17);
	PB_D : INOUT STD_LOGIC_VECTOR(0 TO 15);
	PB_LB_AEN : OUT STD_LOGIC;
	PB_OE_IOR : OUT STD_LOGIC;
	PB_UB_BHE : OUT STD_LOGIC;
	PB_WE_IOW : OUT STD_LOGIC;
	RAM_CE : OUT STD_LOGIC;
	FLASH_CE : OUT STD_LOGIC;
	SDRAM_CE : OUT STD_LOGIC;
	ADC_OE : OUT STD_LOGIC;
	AU_CSN : OUT STD_LOGIC;
	USB_CS : OUT STD_LOGIC;
	NV_CS0 : OUT STD_LOGIC;
	NV_CS1 : OUT STD_LOGIC;
	OPB_Rst : IN STD_LOGIC;
	OPB_ABus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_BE : IN STD_LOGIC_VECTOR(0 TO 3);
	OPB_DBus : IN STD_LOGIC_VECTOR(0 TO 31);
	OPB_RNW : IN STD_LOGIC;
	OPB_select : IN STD_LOGIC;
	OPB_seqAddr : IN STD_LOGIC;
	Sln_DBus : OUT STD_LOGIC_VECTOR(0 TO 31);
	Sln_errAck : OUT STD_LOGIC;
	Sln_retry : OUT STD_LOGIC;
	Sln_toutSup : OUT STD_LOGIC;
	Sln_xferAck : OUT STD_LOGIC);
END sram_ethernet_0_wrapper;

ARCHITECTURE IMP OF sram_ethernet_0_wrapper IS

--------------------------------------------------------------------------------
COMPONENT sram_ethernet IS
GENERIC (
	C_OPB_AWIDTH : INTEGER := 32;
	C_OPB_DWIDTH : INTEGER := 32;
	C_BASEADDR : STD_LOGIC_VECTOR(0 TO 31) := X"00800000";
	C_HIGHADDR : STD_LOGIC_VECTOR(0 TO 31) := X"008fffff");
PORT (
	ETH_CS : OUT STD_LOGIC;
	ETH_IOCS : IN STD_LOGIC;
	ETH_IREQ : IN STD_LOGIC;
	ETH_RDY_DTAK : IN STD_LOGIC;
	OPB_Clk : IN STD_LOGIC;
	PB_A : OUT STD_LOGIC_VECTOR(0 TO 17);
	PB_D : INOUT STD_LOGIC_VECTOR(0 TO 15);
	PB_LB_AEN : OUT STD_LOGIC;
	PB_OE_IOR : OUT STD_LOGIC;
	PB_UB_BHE : OUT STD_LOGIC;
	PB_WE_IOW : OUT STD_LOGIC;
	RAM_CE : OUT STD_LOGIC;
	FLASH_CE : OUT STD_LOGIC;
	SDRAM_CE : OUT STD_LOGIC;
	ADC_OE : OUT STD_LOGIC;
	AU_CSN : OUT STD_LOGIC;
	USB_CS : OUT STD_LOGIC;
	NV_CS0 : OUT STD_LOGIC;
	NV_CS1 : OUT STD_LOGIC;
	OPB_Rst : IN STD_LOGIC;
	OPB_ABus : IN STD_LOGIC_VECTOR(0 TO (C_OPB_AWIDTH-1));
	OPB_BE : IN STD_LOGIC_VECTOR(0 TO ((C_OPB_DWIDTH/8)-1));
	OPB_DBus : IN STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH-1));
	OPB_RNW : IN STD_LOGIC;
	OPB_select : IN STD_LOGIC;
	OPB_seqAddr : IN STD_LOGIC;
	Sln_DBus : OUT STD_LOGIC_VECTOR(0 TO (C_OPB_DWIDTH-1));
	Sln_errAck : OUT STD_LOGIC;
	Sln_retry : OUT STD_LOGIC;
	Sln_toutSup : OUT STD_LOGIC;
	Sln_xferAck : OUT STD_LOGIC);
END COMPONENT;

--------------------------------------------------------------------------------
-- internal signals
--------------------------------------------------------------------------------

BEGIN

--------------------------------------------------------------------------------
-- Power assignments
--------------------------------------------------------------------------------
-- Constant assignments
--------------------------------------------------------------------------------
-- Top-level port assignments
--------------------------------------------------------------------------------
-- Lower-level assignments

--------------------------------------------------------------------------------
sram_ethernet_0_i : sram_ethernet
GENERIC MAP (
	C_OPB_AWIDTH => 32,
	C_OPB_DWIDTH => 32,
	C_BASEADDR => X"00800000",
	C_HIGHADDR => X"008fffff")
PORT MAP (
	ETH_CS => ETH_CS,
	ETH_IOCS => ETH_IOCS,
	ETH_IREQ => ETH_IREQ,
	ETH_RDY_DTAK => ETH_RDY_DTAK,
	OPB_Clk => OPB_Clk,
	PB_A => PB_A,
	PB_D => PB_D,
	PB_LB_AEN => PB_LB_AEN,
	PB_OE_IOR => PB_OE_IOR,
	PB_UB_BHE => PB_UB_BHE,
	PB_WE_IOW => PB_WE_IOW,
	RAM_CE => RAM_CE,
	FLASH_CE => FLASH_CE,
	SDRAM_CE => SDRAM_CE,
	ADC_OE => ADC_OE,
	AU_CSN => AU_CSN,
	USB_CS => USB_CS,
	NV_CS0 => NV_CS0,
	NV_CS1 => NV_CS1,
	OPB_Rst => OPB_Rst,
	OPB_ABus => OPB_ABus,
	OPB_BE => OPB_BE,
	OPB_DBus => OPB_DBus,
	OPB_RNW => OPB_RNW,
	OPB_select => OPB_select,
	OPB_seqAddr => OPB_seqAddr,
	Sln_DBus => Sln_DBus,
	Sln_errAck => Sln_errAck,
	Sln_retry => Sln_retry,
	Sln_toutSup => Sln_toutSup,
	Sln_xferAck => Sln_xferAck);

END ARCHITECTURE IMP;
